# Generated by Django 4.2.20 on 2025-03-13 17:43

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("volunteers", "0005_add_required_permission"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="tasktemplate",
            options={
                "permissions": (
                    ("accept_video_tasks", "Can accept video tasks"),
                    ("accept_talkmeister_tasks", "Can accept talkmeister tasks"),
                    ("accept_fd_tasks", "Can accept front desk tasks"),
                )
            },
        ),
    ]
