const name = 'it';

const localization = {
  today: 'Oggi',
  clear: 'Cancella selezione',
  close: 'Chiudi',
  selectMonth: 'Seleziona mese',
  previousMonth: 'Mese precedente',
  nextMonth: 'Mese successivo',
  selectYear: 'Seleziona anno',
  previousYear: 'Anno precedente',
  nextYear: 'Anno successivo',
  selectDecade: 'Seleziona decennio',
  previousDecade: 'Decennio precedente',
  nextDecade: 'Decennio successivo',
  previousCentury: 'Secolo precedente',
  nextCentury: 'Secolo successivo',
  pickHour: "Seleziona l'ora",
  incrementHour: "Incrementa l'ora",
  decrementHour: "Decrementa l'ora",
  pickMinute: 'Seleziona i minuti',
  incrementMinute: 'Incrementa i minuti',
  decrementMinute: 'Decrementa i minuti',
  pickSecond: 'Seleziona i secondi',
  incrementSecond: 'Incrementa i secondi',
  decrementSecond: 'Decrementa i secondi',
  toggleMeridiem: 'Scambia AM-PM',
  selectTime: "Seleziona l'ora",
  selectDate: 'Seleziona una data',
  dayViewHeaderFormat: { month: 'long', year: '2-digit' },
  locale: 'it',
  startOfTheWeek: 1,
  dateFormats: {
    LT: 'HH:mm',
    LTS: 'HH:mm:ss',
    L: 'dd/MM/yyyy',
    LL: 'd MMMM yyyy',
    LLL: 'd MMMM yyyy HH:mm',
    LLLL: 'dddd d MMMM yyyy HH:mm',
  },
  ordinal: (n) => `${n}º`,
  format: 'L LT',
};

export { localization, name };
