# Generated by Django 4.2.20 on 2025-05-02 20:18

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("minidebconf", "0011_alter_registration_phone_number"),
    ]

    operations = [
        migrations.AddField(
            model_name="registration",
            name="conference_check_in",
            field=models.BooleanField(
                default=False, verbose_name="Checked in to the conference"
            ),
        ),
    ]
