{% load i18n %}

{% if MINIDEBCONF_REGISTRATION and MINIDEBCONF_REGISTRATION.user == object %}
<h2>
  {% blocktrans with conference=WAFER_CONFERENCE_NAME %}
  Your {{ conference }} registration
  {% endblocktrans %}
</h2>
<figure>
  <img src="{% url 'registration_qrcode_image' %}"/>
  <figcaption>
    {% blocktrans with id=MINIDEBCONF_REGISTRATION.id %}
    Your registration ID: {{ id }}.
    {% endblocktrans %}
  </figcaption>
</figure>
<p>
{% blocktrans %}
Print this page (or save it on your phone for offline access) and bring it with
you for easy conference check in.
{% endblocktrans %}
</p>
{% endif %}
