const name = 'ro';

const localization = {
  today: 'Mergi la ziua de astăzi',
  clear: 'Șterge selecția',
  close: 'Închide calendarul',
  selectMonth: 'Selectează luna',
  previousMonth: 'Luna precedentă',
  nextMonth: 'Luna următoare',
  selectYear: 'Selectează anul',
  previousYear: 'Anul precedent',
  nextYear: 'Anul următor',
  selectDecade: 'Selectează deceniul',
  previousDecade: 'Deceniul precedent',
  nextDecade: 'Deceniul următor',
  previousCentury: 'Secolul precedent',
  nextCentury: 'Secolul următor',
  pickHour: 'Alege ora',
  incrementHour: 'Incrementează ora',
  decrementHour: 'Decrementează ora',
  pickMinute: 'Alege minutul',
  incrementMinute: 'Incrementează minutul',
  decrementMinute: 'Decrementează minutul',
  pickSecond: 'Alege secunda',
  incrementSecond: 'Incrementează secunda',
  decrementSecond: 'Decrementează secunda',
  toggleMeridiem: 'Comută modul AM/PM',
  selectTime: 'Selectează ora',
  selectDate: 'Selectează data',
  dayViewHeaderFormat: { month: 'long', year: '2-digit' },
  locale: 'ro',
  startOfTheWeek: 1,
  dateFormats: {
    LT: 'H:mm',
    LTS: 'H:mm:ss',
    L: 'dd.MM.yyyy',
    LL: 'd MMMM yyyy',
    LLL: 'd MMMM yyyy H:mm',
    LLLL: 'dddd, d MMMM yyyy H:mm',
  },
  ordinal: (n) => n,
  format: 'L LT',
};

export { localization, name };
