const name = 'sr';

const localization = {
  today: 'Данас',
  clear: 'Избриши избор',
  close: 'Затвори',
  selectMonth: 'Изабери месец',
  previousMonth: 'Претходни месец',
  nextMonth: 'Следећи месец',
  selectYear: 'Изабери годину',
  previousYear: 'Претходна година',
  nextYear: 'Следећа година',
  selectDecade: 'Изабери декаду',
  previousDecade: 'Претходна декада',
  nextDecade: 'Следећа декада',
  previousCentury: 'Претходни век',
  nextCentury: 'Следећи век',
  pickHour: 'Изабери време',
  incrementHour: 'Повећај време',
  decrementHour: 'Смањи време',
  pickMinute: 'Изабери минуте',
  incrementMinute: 'Повећај минуте',
  decrementMinute: 'Смањи минуте',
  pickSecond: 'Изабери секунде',
  incrementSecond: 'Повећај секунде',
  decrementSecond: 'Смањи секунде',
  toggleMeridiem: 'Размени AM-PM',
  selectTime: 'Изабери време',
  selectDate: 'Изабери датум',
  dayViewHeaderFormat: { month: 'long', year: '2-digit' },
  locale: 'sr',
  startOfTheWeek: 1,
  dateFormats: {
    LT: 'H:mm',
    LTS: 'H:mm:ss',
    L: 'D. M. YYYY.',
    LL: 'D. MMMM YYYY.',
    LLL: 'D. MMMM YYYY. H:mm',
    LLLL: 'dddd, D. MMMM YYYY. H:mm',
  },
  ordinal: (n) => `${n}.`,
  format: 'L LT',
};

export { localization, name };
