# Generated by Django 4.2.20 on 2025-07-07 15:45

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("front_desk", "0003_checkin_bedding"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="checkin",
            name="key_card",
        ),
        migrations.AddField(
            model_name="checkin",
            name="transit_card",
            field=models.BooleanField(default=False),
        ),
    ]
