# Generated by Django 4.2.16 on 2024-12-08 15:58

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("minidebconf", "0009_alter_registration_diet_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="registration",
            name="check_in",
            field=models.DateField(
                blank=True, default=None, null=True, verbose_name="Check-in date"
            ),
        ),
        migrations.AddField(
            model_name="registration",
            name="check_out",
            field=models.DateField(
                blank=True, default=None, null=True, verbose_name="Check-out date"
            ),
        ),
    ]
