# Generated by Django 4.2.25 on 2025-11-04 20:04

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("minidebconf", "0013_checkin"),
    ]

    operations = [
        migrations.AddField(
            model_name="registration",
            name="openpgp_fingerprint",
            field=models.CharField(
                blank=True, max_length=64, null=True, verbose_name="OpenPGP fingerprint"
            ),
        ),
    ]
