# Generated by Django 4.2.20 on 2025-05-03 15:20

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("minidebconf", "0012_registration_conference_check_in"),
    ]

    operations = [
        migrations.CreateModel(
            name="CheckIn",
            fields=[],
            options={
                "proxy": True,
                "indexes": [],
                "constraints": [],
            },
            bases=("minidebconf.registration",),
        ),
    ]
