declare const _default: {
    dateFormats?: {
        L?: string;
        LL?: string;
        LLL?: string;
        LLLL?: string;
        LT?: string;
        LTS?: string;
    };
    format?: string;
    hourCycle?: Intl.LocaleHourCycleKey;
    locale?: string;
    ordinal?: (n: number) => any;
};
export default _default;
