# Generated by Django 4.2.20 on 2025-03-13 15:36

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("register", "0017_security_personal_info"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="attendee",
            options={
                "permissions": [
                    ("orga_early_arrival", "Can arrive extra-early to help setup.")
                ]
            },
        ),
    ]
