const name = 'de';

const localization = {
  today: 'Heute',
  clear: 'Auswahl löschen',
  close: 'Auswahlbox schließen',
  selectMonth: 'Monat wählen',
  previousMonth: 'Letzter Monat',
  nextMonth: 'Nächster Monat',
  selectYear: 'Jahr wählen',
  previousYear: 'Letztes Jahr',
  nextYear: 'Nächstes Jahr',
  selectDecade: 'Jahrzehnt wählen',
  previousDecade: 'Letztes Jahrzehnt',
  nextDecade: 'Nächstes Jahrzehnt',
  previousCentury: 'Letztes Jahrhundert',
  nextCentury: 'Nächstes Jahrhundert',
  pickHour: 'Stunde wählen',
  incrementHour: 'Stunde erhöhen',
  decrementHour: 'Stunde verringern',
  pickMinute: 'Minute wählen',
  incrementMinute: 'Minute erhöhen',
  decrementMinute: 'Minute verringern',
  pickSecond: 'Sekunde wählen',
  incrementSecond: 'Sekunde erhöhen',
  decrementSecond: 'Sekunde verringern',
  toggleMeridiem: 'Tageszeit umschalten',
  selectTime: 'Zeit wählen',
  selectDate: 'Datum wählen',
  dayViewHeaderFormat: { month: 'long', year: '2-digit' },
  locale: 'de',
  startOfTheWeek: 1,
  dateFormats: {
    LTS: 'HH:mm:ss',
    LT: 'HH:mm',
    L: 'dd.MM.yyyy',
    LL: 'd. MMMM yyyy',
    LLL: 'd. MMMM yyyy HH:mm',
    LLLL: 'dddd, d. MMMM yyyy HH:mm',
  },
  ordinal: (n) => `${n}.`,
  format: 'L LT',
};

export { localization, name };
