# Generated by Django 4.2.20 on 2025-03-20 19:26

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("bursary", "0005_alter_bursary_options_bursary_partial_contribution"),
    ]

    operations = [
        migrations.AddField(
            model_name="bursary",
            name="budget",
            field=models.CharField(
                choices=[
                    ("general", "Debian Contributor Bursary"),
                    ("diversity", "Debian Diversity Bursary (newcomers to DebConf)"),
                    ("both", "Debian Contributor and Diversity (considered for both)"),
                ],
                default="both",
                max_length=16,
            ),
            preserve_default=False,
        ),
        migrations.AlterModelOptions(
            name="bursaryreferee",
            options={
                "permissions": [
                    ("invited_speaker", "May have travel funded as a speaker"),
                    ("orga_travel", "May have travel funded as an event organizer"),
                ]
            },
        ),
    ]
