const name = 'cs';

const localization = {
  today: 'Dnes',
  clear: 'Vymazat výběr',
  close: 'Zavřít výběrové okno',
  selectMonth: 'Vybrat měsíc',
  previousMonth: 'Předchozí měsíc',
  nextMonth: 'Následující měsíc',
  selectYear: 'Vybrat rok',
  previousYear: 'Předchozí rok',
  nextYear: 'Následující rok',
  selectDecade: 'Vybrat desetiletí',
  previousDecade: 'Předchozí desetiletí',
  nextDecade: 'Následující desetiletí',
  previousCentury: 'Předchozí století',
  nextCentury: 'Následující století',
  pickHour: 'Vybrat hodinu',
  incrementHour: 'Zvýšit hodinu',
  decrementHour: 'Snížit hodinu',
  pickMinute: 'Vybrat minutu',
  incrementMinute: 'Zvýšit minutu',
  decrementMinute: 'Snížit minutu',
  pickSecond: 'Vybrat sekundu',
  incrementSecond: 'Zvýšit sekundu',
  decrementSecond: 'Snížit sekundu',
  toggleMeridiem: 'Přepnout ráno / odpoledne',
  selectTime: 'Vybrat čas',
  selectDate: 'Vybrat datum',
  dayViewHeaderFormat: { month: 'long', year: '2-digit' },
  locale: 'de',
  startOfTheWeek: 1,
  dateFormats: {
    LTS: 'HH:mm:ss',
    LT: 'HH:mm',
    L: 'dd.MM.yyyy',
    LL: 'd. MMMM yyyy',
    LLL: 'd. MMMM yyyy HH:mm',
    LLLL: 'dddd, d. MMMM yyyy HH:mm',
  },
  ordinal: (n) => `${n}.`,
  format: 'L LT',
};

export { localization, name };
