# Generated by Django 4.2.20 on 2025-06-18 10:22

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("register", "0018_alter_attendee_options"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="attendee",
            options={
                "permissions": [
                    ("orga_early_arrival", "Can arrive extra-early to help setup."),
                    ("view_security_info", "Can view attendees' government identity."),
                ]
            },
        ),
    ]
