const name = 'tr';

const localization = {
  today: 'Bugün',
  clear: 'Temizle',
  close: 'Kapat',
  selectMonth: 'Ay seçin',
  previousMonth: 'Önceki Ay',
  nextMonth: 'Sonraki Ay',
  selectYear: 'Yıl seçin',
  previousYear: 'Önceki yıl',
  nextYear: 'Sonraki yıl',
  selectDecade: 'On yıl seçin',
  previousDecade: 'Önceki on yıl',
  nextDecade: 'Sonraki on yıl',
  previousCentury: 'Önceki yüzyıl',
  nextCentury: 'Sonraki yüzyıl',
  pickHour: 'Saat seçin',
  incrementHour: 'Saati ilerlet',
  decrementHour: 'Saati gerilet',
  pickMinute: 'Dakika seçin',
  incrementMinute: 'Dakikayı ilerlet',
  decrementMinute: 'Dakikayı gerilet',
  pickSecond: 'Saniye seç',
  incrementSecond: 'Saniyeyi ilerlet',
  decrementSecond: 'Saniyeyi gerilet',
  toggleMeridiem: 'Meridemi Değiştir AM-PM',
  selectTime: 'Saat seçin',
  selectDate: 'Tarih seçin',
  dayViewHeaderFormat: { month: 'long', year: 'numeric' },
  locale: 'tr',
  startOfTheWeek: 1,
  dateFormats: {
    LT: 'HH:mm',
    LTS: 'HH:mm:ss',
    L: 'dd.MM.yyyy',
    LL: 'd MMMM yyyy',
    LLL: 'd MMMM yyyy HH:mm',
    LLLL: 'dddd, d MMMM yyyy HH:mm',
  },
  ordinal: (n) => `${n}.`,
  format: 'L LT',
};

export { localization, name };
