/*!
  * Tempus Dominus v6.9.4 (https://getdatepicker.com/)
  * Copyright 2013-2024 Jonathan Peterson
  * Licensed under MIT (https://github.com/Eonasdan/tempus-dominus/blob/master/LICENSE)
  */
(function(g,f){typeof exports==='object'&&typeof module!=='undefined'?f(exports):typeof define==='function'&&define.amd?define(['exports'],f):(g=typeof globalThis!=='undefined'?globalThis:g||self,f((g.tempusDominus=g.tempusDominus||{},g.tempusDominus.locales=g.tempusDominus.locales||{},g.tempusDominus.locales.fr={})));})(this,(function(exports){'use strict';const name = 'fr';
const localization = {
    today: "Aujourd'hui",
    clear: 'Effacer la sélection',
    close: 'Fermer',
    selectMonth: 'Sélectionner le mois',
    previousMonth: 'Mois précédent',
    nextMonth: 'Mois suivant',
    selectYear: "Sélectionner l'année",
    previousYear: 'Année précédente',
    nextYear: 'Année suivante',
    selectDecade: 'Sélectionner la décennie',
    previousDecade: 'Décennie précédente',
    nextDecade: 'Décennie suivante',
    previousCentury: 'Siècle précédente',
    nextCentury: 'Siècle suivante',
    pickHour: "Sélectionner l'heure",
    incrementHour: "Incrementer l'heure",
    decrementHour: "Diminuer l'heure",
    pickMinute: 'Sélectionner les minutes',
    incrementMinute: 'Incrementer les minutes',
    decrementMinute: 'Diminuer les minutes',
    pickSecond: 'Sélectionner les secondes',
    incrementSecond: 'Incrementer les secondes',
    decrementSecond: 'Diminuer les secondes',
    toggleMeridiem: 'Basculer AM-PM',
    selectTime: "Sélectionner l'heure",
    selectDate: 'Sélectionner une date',
    dayViewHeaderFormat: { month: 'long', year: '2-digit' },
    locale: 'fr',
    startOfTheWeek: 1,
    dateFormats: {
        LT: 'HH:mm',
        LTS: 'HH:mm:ss',
        L: 'dd/MM/yyyy',
        LL: 'd MMMM yyyy',
        LLL: 'd MMMM yyyy HH:mm',
        LLLL: 'dddd d MMMM yyyy HH:mm',
    },
    ordinal: (n) => {
        const o = n === 1 ? 'er' : '';
        return `${n}${o}`;
    },
    format: 'L LT',
};exports.localization=localization;exports.name=name;Object.defineProperty(exports,'__esModule',{value:true});}));